==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/original/flow/instructions/instruction/instruction/apply/actions/_case/apply/actions/action/action/NxActionConntrackRpcUpdateFlowOriginalApplyActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.original.flow.instructions.instruction.instruction.apply.actions._case.apply.actions.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionConntrackGrouping;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-conntrack-rpc-update-flow-original-apply-actions-case {
 *     container nx-conntrack {
 *         leaf flags {
 *             type uint16;
 *         }
 *         leaf zone-src {
 *             type uint32;
 *         }
 *         leaf conntrack-zone {
 *             type uint16;
 *         }
 *         leaf recirc-table {
 *             type uint8;
 *         }
 *         list ct-actions {
 *             choice ofpact-actions {
 *                 case nx-action-ct-mark-case {
 *                     container nx-action-ct-mark {
 *                         leaf ct-mark {
 *                             type uint32;
 *                         }
 *                     }
 *                 }
 *                 case nx-action-nat-case {
 *                     container nx-action-nat {
 *                         leaf flags {
 *                             type uint16;
 *                         }
 *                         leaf range_present {
 *                             type uint16;
 *                         }
 *                         leaf ip-address-min {
 *                             type ip-address;
 *                         }
 *                         leaf ip-address-max {
 *                             type ip-address;
 *                         }
 *                         leaf port-min {
 *                             type uint16;
 *                         }
 *                         leaf port-max {
 *                             type uint16;
 *                         }
 *                     }
 *                 }
 *             }
 *             uses ofpact-actions;
 *         }
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-flow/input/original-flow/instructions/instruction/instruction/apply-actions-case/apply-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-conntrack-rpc-update-flow-original-apply-actions-case</i>
 *
 */
public interface NxActionConntrackRpcUpdateFlowOriginalApplyActionsCase
    extends
    DataObject,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.original.flow.instructions.instruction.instruction.apply.actions._case.apply.actions.action.action.NxActionConntrackRpcUpdateFlowOriginalApplyActionsCase>,
    NxActionConntrackGrouping,
    Action
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "nx-action-conntrack-rpc-update-flow-original-apply-actions-case").intern();


}

==> openflowplugin-extension-nicira-0.8.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/original/flow/instructions/instruction/instruction/apply/actions/_case/apply/actions/action/action/NxActionConntrackRpcUpdateFlowOriginalApplyActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.original.flow.instructions.instruction.instruction.apply.actions._case.apply.actions.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionConntrackGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-conntrack-rpc-update-flow-original-apply-actions-case {
 *   uses nx-action-conntrack-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-flow/input/original-flow/instructions/instruction/instruction/apply-actions-case/apply-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-conntrack-rpc-update-flow-original-apply-actions-case</i>
 *
 */
public interface NxActionConntrackRpcUpdateFlowOriginalApplyActionsCase
    extends
    DataObject,
    Augmentable<NxActionConntrackRpcUpdateFlowOriginalApplyActionsCase>,
    NxActionConntrackGrouping,
    Action
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-conntrack-rpc-update-flow-original-apply-actions-case");


}
